@@ -3,7 +3,7 @@ use crate::error::*;
 use crate::holdings::*;
 use crate::promotions::Promotions;
 use chess::{
-    between, get_rank, BitBoard, Board, BoardBuilder, BoardStatus, Piece, Rank,
+    between, get_rank, BitBoard, Board, BoardBuilder, BoardStatus, Color,  Piece, Rank,
     Square, EMPTY,
 };
 use std::convert::TryFrom;
@@ -122,6 +122,10 @@ impl BughouseBoard {
         return Err(Error::IllegalMove(mv.to_string()));
     }
 
+    pub fn side_to_move(&self) -> Color {
+        self.board.side_to_move()
+    }
+
     pub fn is_legal(&self, mv: &BughouseMove) -> bool {
         if mv.get_source() == None {
             if None == mv.get_piece() {
